@@ -18,7 +18,6 @@
 #include "coverinfo.h"
 
 #include <QApplication>
-#include <QRegExp>
 #include <QLabel>
 #include <QCursor>
 #include <QPixmap>
@@ -31,6 +30,7 @@
 #include <QDesktopWidget>
 #include <QImage>
 #include <QScopedPointer>
+#include <QScreen>
 
 #include <taglib/mpegfile.h>
 #include <taglib/tstring.h>
@@ -425,7 +425,8 @@ void CoverInfo::popup() const
 {
     QPixmap image = pixmap(FullSize);
     QPoint mouse  = QCursor::pos();
-    QRect desktop = QApplication::desktop()->screenGeometry(mouse);
+    QScreen *primaryScreen = QApplication::primaryScreen();
+    QRect desktop = primaryScreen->availableGeometry();
 
     int x = mouse.x();
     int y = mouse.y();
