@@ -38,7 +38,6 @@
 #include <QDialogButtonBox>
 #include <QUrl>
 #include <QLabel>
-#include <QSignalMapper>
 #include <QPixmap>
 #include <QFrame>
 #include <QTreeWidget>
@@ -76,7 +75,7 @@ public:
 
         l = new QLabel(i18n("You are about to rename the following files. "
                             "Are you sure you want to continue?"), hbox);
-        hboxVLayout->addWidget(l, 1);
+        hboxVLayout->addWidget(l);
 
         QTreeWidget *lv = new QTreeWidget(this);
 
@@ -86,7 +85,7 @@ public:
 
         lv->setHeaderLabels(headers);
         lv->setRootIsDecorated(false);
-        vboxLayout->addWidget(lv);
+        vboxLayout->addWidget(lv, 1);
 
         auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Yes | QDialogButtonBox::Cancel, this);
         vboxLayout->addWidget(buttonBox);
@@ -271,13 +270,20 @@ FileRenamerWidget::FileRenamerWidget(QWidget *parent) :
         m_ui->m_category->addItem(category);
     }
 
-    connect(m_exampleDialog, SIGNAL(signalShown()), SLOT(exampleDialogShown()));
-    connect(m_exampleDialog, SIGNAL(signalHidden()), SLOT(exampleDialogHidden()));
-    connect(m_exampleDialog, SIGNAL(dataChanged()), SLOT(dataSelected()));
-    connect(m_exampleDialog, SIGNAL(fileChanged(QString)),
-            this,            SLOT(fileSelected(QString)));
-    connect(m_ui->dlgButtonBox, SIGNAL(accepted()), SIGNAL(accepted()));
-    connect(m_ui->dlgButtonBox, SIGNAL(rejected()), SIGNAL(rejected()));
+    connect(m_exampleDialog, &ExampleOptionsDialog::signalShown,
+            this,            &FileRenamerWidget::exampleDialogShown);
+    connect(m_exampleDialog, &ExampleOptionsDialog::signalHidden,
+            this,            &FileRenamerWidget::exampleDialogHidden);
+    connect(m_exampleDialog, &ExampleOptionsDialog::dataChanged,
+            this,            &FileRenamerWidget::dataSelected);
+    connect(m_exampleDialog, &ExampleOptionsDialog::fileChanged,
+            this,            &FileRenamerWidget::fileSelected);
+    connect(m_ui->dlgButtonBox, &QDialogButtonBox::accepted, this, [this]() {
+                emit accepted();
+            });
+    connect(m_ui->dlgButtonBox, &QDialogButtonBox::rejected, this, [this]() {
+                emit rejected();
+            });
 
     exampleTextChanged();
 }
@@ -341,15 +347,14 @@ int FileRenamerWidget::addRowCategory(TagType category)
 
     // Find number of categories already of this type.
     int categoryCount = 0;
-    for(int i = 0; i < m_rows.count(); ++i)
-        if(m_rows[i].category.category == category)
+    for(const auto &row : m_rows)
+        if(row.category.category == category)
             ++categoryCount;
 
     Row row;
 
     row.category = CategoryID(category, categoryCount);
     row.position = m_rows.count();
-    int id = row.position;
 
     QFrame *frame = new QFrame(m_mainFrame);
     QHBoxLayout *frameLayout = new QHBoxLayout(frame);
@@ -376,11 +381,6 @@ int FileRenamerWidget::addRowCategory(TagType category)
     row.upButton->setFlat(true);
     row.downButton->setFlat(true);
 
-    upMapper->connect(row.upButton, SIGNAL(clicked()), SLOT(map()));
-    upMapper->setMapping(row.upButton, id);
-    downMapper->connect(row.downButton, SIGNAL(clicked()), SLOT(map()));
-    downMapper->setMapping(row.downButton, id);
-
     buttonLayout->addWidget(row.upButton);
     buttonLayout->addWidget(row.downButton);
 
@@ -394,30 +394,43 @@ int FileRenamerWidget::addRowCategory(TagType category)
 
     row.enableButton = new QPushButton(i18nc("remove music genre from file renamer", "Remove"), frame);
     optionLayout->addWidget(row.enableButton);
-    toggleMapper->connect(row.enableButton, SIGNAL(clicked()), SLOT(map()));
-    toggleMapper->setMapping(row.enableButton, id);
 
     row.optionsButton = new QPushButton(i18nc("file renamer genre options", "Options"), frame);
     optionLayout->addWidget(row.optionsButton);
-    mapper->connect(row.optionsButton, SIGNAL(clicked()), SLOT(map()));
-    mapper->setMapping(row.optionsButton, id);
 
     row.widget->show();
     m_rows.append(row);
 
+    assignPositionHandlerForRow(row);
+
     // Disable add button if there's too many rows.
     if(m_rows.count() == MAX_CATEGORIES)
         m_ui->m_insertCategory->setEnabled(false);
 
-    return id;
+    return row.position;
 }
 
-void FileRenamerWidget::moveSignalMappings(int oldId, int newId)
+void FileRenamerWidget::assignPositionHandlerForRow(Row &row)
 {
-    mapper->setMapping(m_rows[oldId].optionsButton, newId);
-    downMapper->setMapping(m_rows[oldId].downButton, newId);
-    upMapper->setMapping(m_rows[oldId].upButton, newId);
-    toggleMapper->setMapping(m_rows[oldId].enableButton, newId);
+    const auto id = row.position;
+
+    disconnect(row.upButton);
+    disconnect(row.downButton);
+    disconnect(row.enableButton);
+    disconnect(row.optionsButton);
+
+    connect(row.upButton, &QPushButton::clicked, this, [this, id]() {
+            this->moveItemUp(id);
+        });
+    connect(row.downButton, &QPushButton::clicked, this, [this, id]() {
+            this->moveItemDown(id);
+        });
+    connect(row.enableButton, &QPushButton::clicked, this, [this, id]() {
+            this->slotRemoveRow(id);
+        });
+    connect(row.optionsButton, &QPushButton::clicked, this, [this, id]() {
+            this->showCategoryOption(id);
+        });
 }
 
 bool FileRenamerWidget::removeRow(int id)
@@ -432,13 +445,12 @@ bool FileRenamerWidget::removeRow(int id)
         return false;
     }
 
-    // Remove widget.  Don't delete it since it appears QSignalMapper may still need it.
-    m_rows[id].widget->deleteLater();
-    m_rows[id].widget = 0;
-    m_rows[id].enableButton = 0;
-    m_rows[id].upButton = 0;
-    m_rows[id].optionsButton = 0;
-    m_rows[id].downButton = 0;
+    delete m_rows[id].widget;
+    m_rows[id].widget        = nullptr;
+    m_rows[id].enableButton  = nullptr;
+    m_rows[id].upButton      = nullptr;
+    m_rows[id].optionsButton = nullptr;
+    m_rows[id].downButton    = nullptr;
 
     int checkboxPosition = 0; // Remove first checkbox.
 
@@ -471,9 +483,9 @@ bool FileRenamerWidget::removeRow(int id)
 
     // Every row after the one we delete will have a different identifier, since
     // the identifier is simply its index into m_rows.  So we need to re-do the
-    // signal mappings for the affected rows.
+    // signal mappings for the affected rows after updating its position.
     for(int i = id + 1; i < m_rows.count(); ++i)
-        moveSignalMappings(i, i - 1);
+        assignPositionHandlerForRow(m_rows[i]);
 
     m_rows.erase(&m_rows[id]);
 
@@ -484,7 +496,7 @@ bool FileRenamerWidget::removeRow(int id)
     // We can insert another row now, make sure GUI is updated to match.
     m_ui->m_insertCategory->setEnabled(true);
 
-    QTimer::singleShot(0, this, SLOT(exampleTextChanged()));
+    QTimer::singleShot(0, this, &FileRenamerWidget::exampleTextChanged);
     return true;
 }
 
@@ -500,8 +512,7 @@ void FileRenamerWidget::addFolderSeparatorCheckbox()
     l->addWidget(cb, 0, Qt::AlignCenter);
     cb->setChecked(false);
 
-    connect(cb, SIGNAL(toggled(bool)),
-            SLOT(exampleTextChanged()));
+    connect(cb, &QCheckBox::toggled, this, &FileRenamerWidget::exampleTextChanged);
 
     temp->show();
 }
@@ -518,20 +529,6 @@ void FileRenamerWidget::createTagRows()
     m_rows.reserve(categoryOrder.count());
     m_folderSwitches.reserve(categoryOrder.count() - 1);
 
-    mapper       = new QSignalMapper(this);
-    mapper->setObjectName( QLatin1String("signal mapper" ));
-    toggleMapper = new QSignalMapper(this);
-    toggleMapper->setObjectName( QLatin1String("toggle mapper" ));
-    upMapper     = new QSignalMapper(this);
-    upMapper->setObjectName( QLatin1String("up button mapper" ));
-    downMapper   = new QSignalMapper(this);
-    downMapper->setObjectName( QLatin1String("down button mapper" ));
-
-    connect(mapper,       SIGNAL(mapped(int)), SLOT(showCategoryOption(int)));
-    connect(toggleMapper, SIGNAL(mapped(int)), SLOT(slotRemoveRow(int)));
-    connect(upMapper,     SIGNAL(mapped(int)), SLOT(moveItemUp(int)));
-    connect(downMapper,   SIGNAL(mapped(int)), SLOT(moveItemDown(int)));
-
     m_mainFrame = new QFrame(m_ui->m_mainView);
     m_ui->m_mainView->setWidget(m_mainFrame);
     m_ui->m_mainView->setWidgetResizable(true);
@@ -546,9 +543,7 @@ void FileRenamerWidget::createTagRows()
     // a row given the identifier, use m_rows[id].position.  To find the id of a given
     // position, use idOfPosition(position).
 
-    QList<int>::ConstIterator it = categoryOrder.constBegin();
-
-    for(; it != categoryOrder.constEnd(); ++it) {
+    for(auto it = categoryOrder.cbegin(); it != categoryOrder.cend(); ++it) {
         if(*it < StartTag || *it >= NumTypes) {
             qCCritical(JUK_LOG) << "Invalid category encountered in file renamer configuration.\n";
             continue;
@@ -559,17 +554,12 @@ void FileRenamerWidget::createTagRows()
             break;
         }
 
-        TagType i = static_cast<TagType>(*it);
-
-        addRowCategory(i);
+        addRowCategory(static_cast<TagType>(*it));
 
         // Insert the directory separator checkbox if this isn't the last
         // item.
 
-        QList<int>::ConstIterator dup(it);
-
-        // Check for last item
-        if(++dup != categoryOrder.constEnd())
+        if((it + 1) != categoryOrder.constEnd())
             addFolderSeparatorCheckbox();
     }
 
@@ -730,7 +720,7 @@ void FileRenamerWidget::moveItem(int id, MovementDirection direction)
     layout->insertWidget(2 * pos, w);
     layout->invalidate();
 
-    QTimer::singleShot(0, this, SLOT(exampleTextChanged()));
+    QTimer::singleShot(0, this, &FileRenamerWidget::exampleTextChanged);
 }
 
 int FileRenamerWidget::idOfPosition(int position) const
@@ -761,18 +751,6 @@ int FileRenamerWidget::findIdentifier(const CategoryID &category) const
     return MAX_CATEGORIES;
 }
 
-void FileRenamerWidget::enableAllUpButtons()
-{
-    for(int i = 0; i < m_rows.count(); ++i)
-        m_rows[i].upButton->setEnabled(true);
-}
-
-void FileRenamerWidget::enableAllDownButtons()
-{
-    for(int i = 0; i < m_rows.count(); ++i)
-        m_rows[i].downButton->setEnabled(true);
-}
-
 void FileRenamerWidget::showCategoryOption(int id)
 {
     TagOptionsDialog *dialog = new TagOptionsDialog(this, m_rows[id].options, m_rows[id].category.categoryNumber);
